@@ -1,17 +1,14 @@
 use crossterm::{
     cursor::{Hide, Show},
-    event::{
-        read, DisableMouseCapture, EnableMouseCapture, Event, KeyCode, KeyEvent,
-    },
+    event::{read, DisableMouseCapture, EnableMouseCapture, Event, KeyCode, KeyEvent},
     execute,
     terminal::{
-        disable_raw_mode, enable_raw_mode, EnterAlternateScreen,
-        LeaveAlternateScreen,
+        disable_raw_mode, enable_raw_mode, EnterAlternateScreen, LeaveAlternateScreen,
     },
-    Result,
 };
-use std::io::{stdout, Write};
+use std::io::{stdout, Result, Write};
 use tui_input::backend::crossterm as backend;
+use tui_input::backend::crossterm::EventHandler;
 use tui_input::Input;
 
 fn main() -> Result<()> {
@@ -20,24 +17,20 @@ fn main() -> Result<()> {
     let mut stdout = stdout.lock();
     execute!(stdout, Hide, EnterAlternateScreen, EnableMouseCapture)?;
 
-    let value = "Hello ".to_string();
-    let mut input = Input::default().with_value(value);
+    let mut input: Input = "Hello ".into();
     backend::write(&mut stdout, input.value(), input.cursor(), (0, 0), 15)?;
     stdout.flush()?;
 
     loop {
         let event = read()?;
 
-        match event {
-            Event::Key(KeyEvent { code, .. }) => match code {
+        if let Event::Key(KeyEvent { code, .. }) = event {
+            match code {
                 KeyCode::Esc | KeyCode::Enter => {
                     break;
                 }
                 _ => {
-                    if backend::to_input_request(event)
-                        .and_then(|r| input.handle(r))
-                        .is_some()
-                    {
+                    if input.handle_event(&event).is_some() {
                         backend::write(
                             &mut stdout,
                             input.value(),
@@ -48,13 +41,12 @@ fn main() -> Result<()> {
                         stdout.flush()?;
                     }
                 }
-            },
-            _ => {}
+            }
         }
     }
 
     execute!(stdout, Show, LeaveAlternateScreen, DisableMouseCapture)?;
     disable_raw_mode()?;
-    println!("{}", input.value());
+    println!("{}", input);
     Ok(())
 }
